@@ -2,9 +2,7 @@
  * VisPatch :  Quake level patcher for water visibility.
  *
  * Copyright (C) 1997-2006  Andy Bay <IMarvinTPA@bigfoot.com>
- * Copyright (C) 2006-2011  O. Sezer <sezero@users.sourceforge.net>
- *
- * $Id: vispatch.c,v 1.13 2011/10/08 12:33:03 sezero Exp $
+ * Copyright (C) 2006-2024  O. Sezer <sezero@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,13 +39,13 @@ static int		mode = 0;	/* 0: patch, 2: patch without overwriting, 1: extract	*/
 static FILE	*InFile, *OutFile, *fVIS;
 
 #define		TEMP_FILE_NAME		"~vistmp.tmp"
-static char	Path[256],	/* where we shall work: getcwd(), changed by -dir	*/
-		Path2[256],	/* temporary filename buffer				*/
-		TempFile[256],	/* name of our temporary file on disk			*/
-		VIS[256] = "vispatch.dat",	/* vis data filename. changed by -data	*/
-		FoutPak[256] = "pak*.pak",	/* name of the output pak file		*/
-		File[256] = "pak*.pak",		/* filename pattern we'll be globbing	*/
-		CurName[VISPATCH_IDLEN+6];	/* name of the currently processed file	*/
+static char	Path[MAX_OSPATH];	/* where we shall work: getcwd(), changed by -dir	*/
+static char	Path2[MAX_OSPATH];	/* temporary filename buffer				*/
+static char	TempFile[MAX_OSPATH];	/* name of our temporary file on disk			*/
+static char	VIS[MAX_OSPATH] = "vispatch.dat";	/* vis data filename. changed by -data	*/
+static char	FoutPak[MAX_OSPATH] = "pak*.pak";	/* name of the output pak file		*/
+static char	File[MAX_OSPATH] = "pak*.pak";		/* filename pattern we'll be globbing	*/
+static char	CurName[VISPATCH_IDLEN + 6];	/* name of the currently processed file.	*/
 
 
 /*============================================================================*/
@@ -79,7 +77,6 @@ do {								\
 		fclose(fVIS);					\
 } while (0)
 
-
 #define FWRITE_ERROR						\
 do {								\
 	CLOSE_ALL;						\
@@ -141,7 +138,7 @@ static void usage (void)
 
 /*============================================================================*/
 
-#if (defined(__MINGW32__) || defined(__MINGW64__))
+#if defined(__MINGW32__)
 
 /* From MinGW runtime/init.c :
  * [...] GetMainArgs (used below) takes a fourth argument
@@ -157,15 +154,15 @@ static void usage (void)
  */
 int	_CRT_glob = 0;
 
-#endif	/* __MINGW32__ / __MINGW64__ */
+#endif	/* __MINGW32__ */
 
 
 static const char authors[] = "Andy Bay, O. Sezer";
 
 int main (int argc, char **argv)
 {
-	int	ret = 0, tmp;
-	char	*testname;
+	int	ret = 0, tmp, len;
+	const char	*testname;
 
 	printf("VisPatch %d.%d.%d by %s\n",
 			 VP_VER_MAJ, VP_VER_MID, VP_VER_MIN,
@@ -173,67 +170,62 @@ int main (int argc, char **argv)
 
 	ValidateByteorder ();
 
-	if (argc > 1)
-	{
-		for (tmp = 1; tmp < argc; tmp++)
-		{
-			if (argv[tmp][0] == '/')
-				argv[tmp][0] = '-';
-
-			q_strlwr(argv[tmp]);
-			if (strcmp(argv[tmp], "-?"    ) == 0 ||
-			    strcmp(argv[tmp], "-h"    ) == 0 ||
-			    strcmp(argv[tmp], "-help" ) == 0 ||
-			    strcmp(argv[tmp], "--help") == 0 )
-			{
-				usage();
-				exit (0);
-			}
-		}
-	}
-
-	if ( Sys_getcwd(Path,sizeof(Path)) != 0)
+	if (Sys_getcwd(Path,sizeof(Path)) != 0)
 		Error ("Unable to determine current working directory");
 	printf("Current directory: %s\n", Path);
 
 	if (argc > 1)
 	{
+		char *cmdbuffer = TempFile;
 		for (tmp = 1; tmp < argc; tmp++)
 		{
-			if (argv[tmp][0] == '-')
+			q_strlcpy(cmdbuffer, argv[tmp], MAX_OSPATH);
+			q_strlwr(cmdbuffer);
+			if (cmdbuffer[0] == '/')
 			{
-				if (strcmp(argv[tmp],"-data") == 0)
-				{
-					argv[tmp][0] = 0;
-					if (++tmp == argc)
-						Error ("You must specify the filename of visdata after -data");
-					q_strlcpy (VIS, argv[tmp], sizeof(VIS));
-					argv[tmp][0] = 0;
-				}
-				else if (strcmp(argv[tmp],"-dir") == 0)
-				{
-					argv[tmp][0] = 0;
-					if (++tmp == argc)
-						Error ("You must specify a directory name after -dir");
-					q_strlcpy (Path, argv[tmp], sizeof(Path) - 1);
-					Path[sizeof(Path) - 1] = 0;
-					argv[tmp][0] = 0;
-					printf("Will look into %s as the pak/bsp directory..\n", Path);
-				}
-				else if (strcmp(argv[tmp],"-extract") == 0)
-				{
-					if (mode == 2)
-						Error ("-extract and -new cannot be used together");
-					mode = 1;
-					argv[tmp][0] = 0;
-				}
-				else if (strcmp(argv[tmp],"-new") == 0)
-				{
-					if (mode == 1)
-						Error ("-extract and -new cannot be used together");
-					mode = 2;
-					argv[tmp][0] = 0;
-				}
+				cmdbuffer[0] = '-';
+			}
+			if (strcmp(cmdbuffer, "-?"    ) == 0 ||
+			    strcmp(cmdbuffer, "-h"    ) == 0 ||
+			    strcmp(cmdbuffer, "-help" ) == 0 ||
+			    strcmp(cmdbuffer, "--help") == 0 )
+			{
+				usage();
+				exit (0);
+			}
+			else if (strcmp(cmdbuffer,"-data") == 0)
+			{
+				argv[tmp][0] = 0;
+				if (++tmp == argc)
+					Error ("You must specify the filename of visdata after -data");
+				q_strlcpy (VIS, argv[tmp], sizeof(VIS));
+				argv[tmp][0] = 0;
+			}
+			else if (strcmp(cmdbuffer,"-dir") == 0)
+			{
+				argv[tmp][0] = 0;
+				if (++tmp == argc)
+					Error ("You must specify a directory name after -dir");
+				q_strlcpy (Path, argv[tmp], sizeof(Path));
+				len = (int)strlen(Path) - 1;
+				if (Path[len] == '/' || Path[len] == '\\')
+					Path[len] = 0;
+				argv[tmp][0] = 0;
+				printf("Will look into %s as the pak/bsp directory..\n", Path);
+			}
+			else if (strcmp(cmdbuffer,"-extract") == 0)
+			{
+				if (mode == 2)
+					Error ("-extract and -new cannot be used together");
+				mode = 1;
+				argv[tmp][0] = 0;
+			}
+			else if (strcmp(cmdbuffer,"-new") == 0)
+			{
+				if (mode == 1)
+					Error ("-extract and -new cannot be used together");
+				mode = 2;
+				argv[tmp][0] = 0;
 			}
 			else
 			{
@@ -244,6 +236,7 @@ int main (int argc, char **argv)
 
 	printf("VisPatch is in mode %i\n", mode);
 	printf("Will use %s as the Vis-data source\n", VIS);
+	printf("Will patch files matching %s/%s\n", Path, File);
 	if (mode == 1)
 	{
 		printf("Will extract Vis data to %s, auto-append.\n", VIS);
@@ -420,7 +413,7 @@ static int ChooseLevel (char *FileSpec, int Offset, int length)
 	int tmp = 0;
 
 //	printf("Looking at file %s %i %i.\n", FileSpec, length, mode);
-	if ( strstr(q_strlwr(FileSpec),".pak") )
+	if (strstr(q_strlwr(FileSpec),".pak"))
 	{
 		printf("Looking at file %s.\n", FileSpec);
 		usepak = 1;
@@ -521,11 +514,11 @@ static int OthrFix (int Offset, int Length)
 	void		*cpy;
 
 	fseek(InFile, Offset, SEEK_SET);
-	NewPakEnt[NPcnt].offset = LittleLong( ftell(OutFile) );
-	NewPakEnt[NPcnt].size = LittleLong( Length );
+	NewPakEnt[NPcnt].offset = LittleLong(ftell(OutFile));
+	NewPakEnt[NPcnt].size = LittleLong(Length);
 	cpy = malloc(Length);
 	fread(cpy, 1, Length, InFile);
-	test = fwrite(cpy, 1, Length, OutFile);
+	test = (int) fwrite(cpy, 1, Length, OutFile);
 	free(cpy);
 
 	if (test != Length)
@@ -544,10 +537,10 @@ static int BSPFix (int InitOFFS)
 	char	pad[4] = { 0, 0, 0, 0 };
 
 	fflush(OutFile);
-	NewPakEnt[NPcnt].offset = LittleLong( ftell(OutFile) );
+	NewPakEnt[NPcnt].offset = LittleLong(ftell(OutFile));
 	tmp = LittleLong(NewPakEnt[NPcnt].size);
 	if (tmp == 0)
-		NewPakEnt[NPcnt].size = LittleLong( Sys_filesize(File) );
+		NewPakEnt[NPcnt].size = LittleLong(Sys_filesize(File));
 
 	fseek(InFile, InitOFFS, SEEK_SET);
 	test = fread(&bspheader, 1, sizeof(dheader_t), InFile);
@@ -849,7 +842,7 @@ static int BSPFix (int InitOFFS)
 		return -1;
 
 	fseek(OutFile, here, SEEK_SET);
-	NewPakEnt[NPcnt].size = LittleLong( ftell(OutFile) - LittleLong(NewPakEnt[NPcnt].offset) );
+	NewPakEnt[NPcnt].size = LittleLong(ftell(OutFile) - LittleLong(NewPakEnt[NPcnt].offset));
 
 	return 1;
 }
@@ -962,7 +955,7 @@ static int BSPNew (int InitOFFS)
 	if (len > -1)
 		fseek(fVIS, 0, SEEK_END);
 
-	test = fwrite(&VisName, 1, VISPATCH_IDLEN, fVIS);
+	test = fwrite(VisName, 1, VISPATCH_IDLEN, fVIS);
 	if (test != VISPATCH_IDLEN)
 		return -1;
 
